Class: DefraRubyMocks::Configuration
- Inherits:
-
Object
- Object
- DefraRubyMocks::Configuration
- Defined in:
- lib/defra_ruby_mocks/configuration.rb
Constant Summary collapse
- DEFAULT_DELAY =
1000
Instance Attribute Summary collapse
-
#delay ⇒ Object
Returns the value of attribute delay.
Instance Method Summary collapse
-
#enable=(arg) ⇒ Object
Controls whether the mocks are enabled.
- #enabled? ⇒ Boolean
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
10 11 12 13 |
# File 'lib/defra_ruby_mocks/configuration.rb', line 10 def initialize @enable = false @delay = DEFAULT_DELAY end |
Instance Attribute Details
#delay ⇒ Object
Returns the value of attribute delay.
8 9 10 |
# File 'lib/defra_ruby_mocks/configuration.rb', line 8 def delay @delay end |
Instance Method Details
#enable=(arg) ⇒ Object
Controls whether the mocks are enabled. Only if set to true will the mock pages be accessible
17 18 19 20 21 22 23 |
# File 'lib/defra_ruby_mocks/configuration.rb', line 17 def enable=(arg) # We implement our own setter to handle values being passed in as strings # rather than booleans parsed = arg.to_s.downcase @enable = parsed == "true" end |
#enabled? ⇒ Boolean
25 26 27 |
# File 'lib/defra_ruby_mocks/configuration.rb', line 25 def enabled? @enable end |